##########
User Guide
##########

This guide serves as an overview of key features in the MusicBox library. Further details can be found in the :ref:`API Reference <api-ref>`.
Interactive Jupyter notebooks can also be found on our `GitHub <https://github.com/NCAR/music-box/tree/main/tutorial>`_.

.. note::
   Most chemistry classes (e.g., `Species`, `Phase`, `Mechanism`) are provided by the underlying `MUSICA <https://github.com/NCAR/musica>`_ framework. Refer to the `MUSICA documentation <https://ncar.github.io/musica/index.html#>`_
   for full details on these classes and their parameters.

.. toctree::
   :maxdepth: 2
   :caption: Configuration Files

   configuration/index

.. toctree::
   :maxdepth: 2
   :caption: Python

   installation/index
   chemistry/index
   box_model/index
   output/index
   examples/index

.. toctree::
   :maxdepth: 2
   :caption: JavaScript

   javascript/index
